const { src, dest, watch, series, parallel, lastRun } = require('gulp');
const sass = require('gulp-sass');
sass.compiler = require('sass');
const sassGlob = require('gulp-sass-glob-use-forward');
const autoprefixer = require('gulp-autoprefixer');
const cleanCss = require('gulp-clean-css');
const plumber = require('gulp-plumber');
const notify = require('gulp-notify');
const rename = require('gulp-rename');
const browserSync = require('browser-sync');
const imagemin = require('gulp-imagemin');
const pngquant = require('imagemin-pngquant');
const mozjpeg = require('imagemin-mozjpeg');
const webpack = require('webpack');
const webpackStream = require('webpack-stream');
const webpackConfig = require('./webpack.config');
const minimist = require('minimist');

const wpLocalUrl = 'localhost:8000';
const wpThemeName = 'theme';
const wpDir = './wp-content/themes/' + wpThemeName + '/';
const mode = require('gulp-mode')({
  modes: ['prod', 'dev'],
  default: 'dev',
  verbose: false,
});

// npxから引数を渡せるように
const options = minimist(process.argv.slice(2), {
	string: 'path',
	default: {
		path: wpLocalUrl,
	},
});

// ローカルサーバ起動
const buildServer = (done) => {
  browserSync.init({
    files: [wpDir + '**/*.php'],
		proxy: {
			target: options.path,
		},
  });
  done();
};

// ブラウザ自動リロード
const browserReload = (done) => {
  browserSync.reload();
  done();
};

// Sassコンパイル
const compileSass = (done) => {
  src('src/styles/*.scss', { sourcemaps: true })
    .pipe(plumber({ errorHandler: notify.onError('Error: <%= error.message %>') }))
    .pipe(sassGlob()) //importをディレクトリ単位で
    .pipe(sass({ outputStyle: 'expanded' }))
		.pipe(autoprefixer())
    .pipe(
      rename(function (path) {
		path.dirname = '/';
        path.extname = '.min.css';
      })
    )
    .pipe(mode.prod(cleanCss()))
    .pipe(dest(wpDir + 'assets/css/'));
  done();
};

// webpack
const bundleJs = () => {
  return webpackStream(webpackConfig, webpack)
    .pipe(dest(wpDir + 'assets/js/'))
};

// 画像圧縮
const images = (done) => {
  src('src/images/**/*', { since: lastRun(images) })
    .pipe(
      mode.prod(
        imagemin([
          pngquant({
            quality: [0.7, 0.85],
            speed: 1,
            floyd: 0,
          }),
          mozjpeg({
            quality: 85,
            progressive: true,
          }),
          imagemin.optipng(),
          imagemin.gifsicle(),
        ])
      )
    )
    .pipe(dest(wpDir + 'assets/images/'))
  done();
};

// watchするフォルダ
const watchFiles = () => {
  watch('./src/styles/**/*.scss', series(compileSass, browserReload));
  watch('./src/js/**/*.js', series(bundleJs, browserReload));
  watch('./src/images/**/*', series(images, browserReload));
};
// 開発環境実行コマンド
exports.default = parallel(buildServer, watchFiles);

// 本番環境実行コマンド
exports.build = parallel(compileSass, bundleJs, images);
