<?php

/**
 * Functions
 *
 * @package WordPress
 */

/**
 * CSS読み込み
 *
 * @return void
 */
function add_stylesheet()
{
	// キャッシュ対策 本番UP時は wp_get_theme()->get('Version')を有効にする
	$theme_ver = date('YmdHi');
	// $theme_ver = wp_get_theme()->get('Version');

	wp_enqueue_style('font-googleapis', 'https://fonts.googleapis.com', array(), $theme_ver, false);
	wp_enqueue_style('font-gstatic', 'https://fonts.gstatic.com', array(), $theme_ver, false);
	wp_enqueue_style('font', 'https://fonts.googleapis.com/css2?family=Noto+Serif+JP:wght@300;400;500;600;700;900&display=swap', array(), $theme_ver, false);
	wp_enqueue_style('style', get_template_directory_uri() . '/assets/css/style.min.css', array(), $theme_ver, false);
}
add_action('wp_enqueue_scripts', 'add_stylesheet');
add_filter('style_loader_tag', 'add_preconnect_to_style', 10, 3);

/**
 * Googleフォントを読み込む時に属性をlinkタグに追加
 *
 * @param string $tag スクリプトのURL全体.
 * @param string $handle スクリプトの登録名.
 * @param string $url スクリプトのURL.
 * @return string
 */
function add_preconnect_to_style($tag, $handle, $url)
{
	if ('font-googleapis' === $handle) {
		$tag = '<link
		href="' . esc_url($url) . '" rel="preconnect"></link>';
	} elseif ('font-gstatic' === $handle) {
		$tag = '<link
		href="' . esc_url($url) . '" rel="preconnect" crossorigin></link>';
	}

	return $tag;
}


/**
 * JS読込
 *
 * @return void
 */
function add_script()
{
	// キャッシュ対策 本番UP時は wp_get_theme()->get('Version')を有効にする
	$theme_ver = date('YmdHi');
	// $theme_ver = wp_get_theme()->get('Version');

	wp_enqueue_script('lazysizes', 'https://cdnjs.cloudflare.com/ajax/libs/lazysizes/5.3.0/lazysizes.min.js', array(), $theme_ver, true);
	wp_enqueue_script('lazysizes-aspectratio', 'https://cdnjs.cloudflare.com/ajax/libs/lazysizes/5.3.0/plugins/aspectratio/ls.aspectratio.min.js', array(), $theme_ver, true);
	wp_enqueue_script('theme-bundle', get_template_directory_uri() . '/assets/js/bundle.min.js', array(), $theme_ver, true);
}
add_action('wp_enqueue_scripts', 'add_script');



/**
 * アイキャッチ画像を表示する
 */
function theme_setup()
{
	add_theme_support('post-thumbnails');
}
add_action('after_setup_theme', 'theme_setup');

/**
 * type属性を削除(W3Cチェックのため)
 */
add_theme_support('html5', array('script', 'style'));
